---
name: "\U0001F41BBug report"
about: Create a report to help us improve.

---

**Environment (please complete the following information):**
 - multiple-cucumber-html-reporter: [e.g. 1.10.0]
 - Node.js version: [e.g. 8.9.1]
 - NPM version: [e.g. 5.8.0]
 - Platform name and version: [e.g. Windows 10]
 - Cucucmber version: [e.g. 4.2.0]

**Config of multiple-cucumber-html-reporter**
An example of how you configured the reporter in your config

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

[Include code or an example repository that can easily be set up]

**Expected behavior**
A clear and concise description of what you expected to happen.

**Log**
If applicable, add logs to help explain your problem. If you don't have log, enable 'debug:true' in the config and paste the log here.
Please use proper markdown to style it

**Additional context**
Add any other context about the problem here.
